@@ -3,12 +3,11 @@ from pathlib import Path
 
 def quick_template():
     """Provides a template for using this library."""
+
     example_path = Path(__file__).parent / 'examples/example.py'
+    error_message = "# uh oh! This example failed to load."
+
     inline_example(
         example_path=example_path,
-        write_mode='w+')
-
-# now your user could call this:
-
-# from yourpackage.your_module import quick_template
-# quick_template()
\ No newline at end of file
+        write_mode='w+',
+        error_message=error_message)
